
# Class: physical essence or occurrent


Either a physical or processual entity.

URI: [biolink:PhysicalEssenceOrOccurrent](https://w3id.org/biolink/vocab/PhysicalEssenceOrOccurrent)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[PhysicalEssenceOrOccurrent]^-[PhysicalEssence],[PhysicalEssenceOrOccurrent]^-[Occurrent],[PhysicalEssence],[Occurrent])](https://yuml.me/diagram/nofunky;dir:TB/class/[PhysicalEssenceOrOccurrent]^-[PhysicalEssence],[PhysicalEssenceOrOccurrent]^-[Occurrent],[PhysicalEssence],[Occurrent])

## Children

 * [Occurrent](Occurrent.md) - A processual entity.
 * [PhysicalEssence](PhysicalEssence.md) - Semantic mixin concept.  Pertains to entities that have physical properties such as mass, volume, or charge.

## Referenced by Class

 *  **[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)** *[negatively regulated by](negatively_regulated_by.md)*  <sub>0..1</sub>  **[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)**
 *  **[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)** *[negatively regulates](negatively_regulates.md)*  <sub>0..1</sub>  **[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)**
 *  **[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)** *[positively regulated by](positively_regulated_by.md)*  <sub>0..1</sub>  **[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)**
 *  **[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)** *[positively regulates](positively_regulates.md)*  <sub>0..1</sub>  **[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)**
 *  **[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)** *[regulated by](regulated_by.md)*  <sub>0..1</sub>  **[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)**
 *  **[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)** *[regulates](regulates.md)*  <sub>0..1</sub>  **[PhysicalEssenceOrOccurrent](PhysicalEssenceOrOccurrent.md)**

## Attributes

